# libpythonmax
Módulo para exemplificar construção de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto

Perfil Gitbub: [maxProgrammer](https://github.com/maxProgrammer)

[![Build Status](https://app.travis-ci.com/maxProgrammer/api-github.svg?branch=main)](https://app.travis-ci.com/maxProgrammer/api-github)

Suportada versão 3 de Python 

Atenção => Travis-ci não funciona no archlinux e seus derivados.

Para instalar:
"""
console:
python3 -m venv .venv
source .venv/bin/activate
pip install - r requirements-dev.txt 
"""

Para conferir qualidade do código PEP8:
flake8

Tópicos a serem abordados:
1. Git
2. Pyenv
3. PIP
